==> uicdm-5.3.3-sources.jar: ucar/nc2/ui/op/Hdf5ObjectPanel.java <==
/*
 * Copyright (c) 1998-2019 University Corporation for Atmospheric Research/Unidata
 * See LICENSE for license information.
 */

package ucar.nc2.ui.op;

import ucar.nc2.ui.OpPanel;
import ucar.ui.widget.BAMutil;
import ucar.unidata.io.RandomAccessFile;
import ucar.util.prefs.PreferencesExt;
import java.awt.BorderLayout;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.PrintWriter;
import java.io.StringWriter;
import java.util.Formatter;
import javax.swing.AbstractButton;
import javax.swing.JOptionPane;

public class Hdf5ObjectPanel extends OpPanel {
  RandomAccessFile raf;
  Hdf5ObjectTable hdf5Table;

  public Hdf5ObjectPanel(PreferencesExt p, boolean useBuilders) {
    super(p, "file:", true, false);
    hdf5Table = useBuilders ? new Hdf5NewObjectTable(prefs) : new Hdf5ObjectTable(prefs);
    add(hdf5Table, BorderLayout.CENTER);

    AbstractButton infoButton = BAMutil.makeButtcon("Information", "Compact Representation", false);
    infoButton.addActionListener(e -> {
      Formatter f = new Formatter();
      try {
        hdf5Table.showInfo(f);
      } catch (IOException ioe) {
        StringWriter sw = new StringWriter(5000);
        ioe.printStackTrace(new PrintWriter(sw));
        detailTA.setText(sw.toString());
        detailWindow.show();
        return;
      }
      detailTA.setText(f.toString());
      detailTA.gotoTop();
      detailWindow.show();
    });
    buttPanel.add(infoButton);

    AbstractButton infoButton2 = BAMutil.makeButtcon("Information", "Detail Info", false);
    infoButton2.addActionListener(e -> {
      Formatter f = new Formatter();
      try {
        hdf5Table.showInfo2(f);
      } catch (IOException ioe) {
        StringWriter sw = new StringWriter(5000);
        ioe.printStackTrace(new PrintWriter(sw));
        detailTA.setText(sw.toString());
        detailWindow.show();
        return;
      }
      detailTA.setText(f.toString());
      detailTA.gotoTop();
      detailWindow.show();
    });
    buttPanel.add(infoButton2);

    AbstractButton eosdump = BAMutil.makeButtcon("alien", "Show EOS processing", false);
    eosdump.addActionListener(e -> {
      try {
        Formatter f = new Formatter();
        hdf5Table.getEosInfo(f);
        detailTA.setText(f.toString());
        detailWindow.show();
      } catch (IOException ioe) {
        StringWriter sw = new StringWriter(5000);
        ioe.printStackTrace(new PrintWriter(sw));
        detailTA.setText(sw.toString());
        detailWindow.show();
      }
    });
    buttPanel.add(eosdump);

  }

  @Override
  public boolean process(Object o) {
    String command = (String) o;
    boolean err = false;

    try {
      if (raf != null) {
        raf.close();
      }
      raf = new RandomAccessFile(command, "r");

      hdf5Table.setHdf5File(raf);
    } catch (FileNotFoundException ioe) {
      JOptionPane.showMessageDialog(null, "Hdf5ObjectTable cannot open " + command + "\n" + ioe.getMessage());
      err = true;
    } catch (Exception e) {
      StringWriter sw = new StringWriter(5000);
      e.printStackTrace(new PrintWriter(sw));
      detailTA.setText(sw.toString());
      detailWindow.show();
      err = true;
    }

    return !err;
  }

  @Override
  public void closeOpenFiles() throws IOException {
    hdf5Table.closeOpenFiles();
  }

  @Override
  public void save() {
    hdf5Table.save();
    super.save();
  }
}

==> uicdm-6.0.0-20220119.080825-58-sources.jar: ucar/nc2/ui/op/Hdf5ObjectPanel.java <==
/*
 * Copyright (c) 1998-2019 University Corporation for Atmospheric Research/Unidata
 * See LICENSE for license information.
 */

package ucar.nc2.ui.op;

import ucar.nc2.ui.OpPanel;
import ucar.ui.widget.BAMutil;
import ucar.unidata.io.RandomAccessFile;
import ucar.util.prefs.PreferencesExt;
import java.awt.BorderLayout;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.PrintWriter;
import java.io.StringWriter;
import java.util.Formatter;
import javax.swing.AbstractButton;
import javax.swing.JOptionPane;

public class Hdf5ObjectPanel extends OpPanel {
  final Hdf5ObjectTable hdf5Table;
  RandomAccessFile raf;

  public Hdf5ObjectPanel(PreferencesExt p, boolean useBuilders) {
    super(p, "file:", true, false);
    hdf5Table = useBuilders ? new Hdf5NewObjectTable(prefs) : new Hdf5ObjectTable(prefs);
    add(hdf5Table, BorderLayout.CENTER);

    AbstractButton infoButton = BAMutil.makeButtcon("Information", "Compact Representation", false);
    infoButton.addActionListener(e -> {
      Formatter f = new Formatter();
      hdf5Table.showInfo(f);
      detailTA.setText(f.toString());
      detailTA.gotoTop();
      detailWindow.show();
    });
    buttPanel.add(infoButton);

    AbstractButton infoButton2 = BAMutil.makeButtcon("Information", "Detail Info", false);
    infoButton2.addActionListener(e -> {
      Formatter f = new Formatter();
      try {
        hdf5Table.showInfo2(f);
      } catch (IOException ioe) {
        StringWriter sw = new StringWriter(5000);
        ioe.printStackTrace(new PrintWriter(sw));
        detailTA.setText(sw.toString());
        detailWindow.show();
        return;
      }
      detailTA.setText(f.toString());
      detailTA.gotoTop();
      detailWindow.show();
    });
    buttPanel.add(infoButton2);

    AbstractButton eosdump = BAMutil.makeButtcon("alien", "Show EOS processing", false);
    eosdump.addActionListener(e -> {
      try {
        Formatter f = new Formatter();
        hdf5Table.getEosInfo(f);
        detailTA.setText(f.toString());
        detailWindow.show();
      } catch (IOException ioe) {
        StringWriter sw = new StringWriter(5000);
        ioe.printStackTrace(new PrintWriter(sw));
        detailTA.setText(sw.toString());
        detailWindow.show();
      }
    });
    buttPanel.add(eosdump);
  }

  @Override
  public boolean process(Object o) {
    String command = (String) o;
    boolean err = false;

    try {
      if (raf != null) {
        raf.close();
      }
      raf = new RandomAccessFile(command, "r");

      hdf5Table.setHdf5File(raf);
    } catch (FileNotFoundException ioe) {
      JOptionPane.showMessageDialog(null, "Hdf5ObjectTable cannot open " + command + "\n" + ioe.getMessage());
      err = true;
    } catch (Exception e) {
      StringWriter sw = new StringWriter(5000);
      e.printStackTrace(new PrintWriter(sw));
      detailTA.setText(sw.toString());
      detailWindow.show();
      err = true;
    }

    return !err;
  }

  @Override
  public void closeOpenFiles() throws IOException {
    hdf5Table.closeOpenFiles();
  }

  @Override
  public void save() {
    hdf5Table.save();
    super.save();
  }
}
